==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/inc/lang/zh/lang.php <==
<?php
/**
 * Chinese(Simplified) language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html) 
 * @author ZDYX <zhangduyixiong@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = '编辑本页';
$lang['btn_source']            = '显示源文件';
$lang['btn_show']              = '显示页面';
$lang['btn_create']            = '创建该页面';
$lang['btn_search']            = '搜索';
$lang['btn_save']              = '保存';
$lang['btn_preview']           = '预览';
$lang['btn_top']               = '到顶部';
$lang['btn_newer']             = '<< 较新的';
$lang['btn_older']             = '较旧的 >>';
$lang['btn_revs']              = '修订记录';
$lang['btn_recent']            = '最近更改';
$lang['btn_upload']            = '上传';
$lang['btn_cancel']            = '取消';
$lang['btn_index']             = '索引';
$lang['btn_secedit']           = '编辑';
$lang['btn_login']             = '登录';
$lang['btn_logout']            = '退出';
$lang['btn_admin']             = '管理';
$lang['btn_update']            = '更新';
$lang['btn_delete']            = '删除';
$lang['btn_back']              = '返回';
$lang['btn_backlink']          = '反向链接';
$lang['btn_backtomedia']       = '返回到媒体文件选择工具';
$lang['btn_subscribe']         = '订阅本页更改';
$lang['btn_unsubscribe']       = '退订本页更改';
$lang['btn_subscribens']       = '订阅命名空间更改';
$lang['btn_unsubscribens']     = '退订命名空间更改';
$lang['btn_profile']           = '更新个人信息';
$lang['btn_reset']             = '重设';
$lang['btn_resendpwd']         = '发送新密码';
$lang['btn_draft']             = '编辑草稿';
$lang['btn_recover']           = '恢复草稿';
$lang['btn_draftdel']          = '删除草稿';
$lang['loggedinas']            = '登录为';
$lang['user']                  = '用户名';
$lang['pass']                  = '密码';
$lang['newpass']               = '请输入新密码';
$lang['oldpass']               = '请输入当前密码';
$lang['passchk']               = '请再输一次';
$lang['remember']              = '记住我';
$lang['fullname']              = '全名';
$lang['email']                 = 'E-Mail';
$lang['register']              = '注册';
$lang['profile']               = '用户信息';
$lang['badlogin']              = '对不起，用户名或密码错误。';
$lang['minoredit']             = '轻微修改';
$lang['draftdate']             = '草稿自动保存于';
$lang['regmissing']            = '对不起，您必须填写所有的区域。';
$lang['reguexists']            = '对不起，该用户名已经存在。';
$lang['regsuccess']            = '新用户已建立，密码将通过电子邮件发送给您。';
$lang['regsuccess2']           = '新用户已建立';
$lang['regmailfail']           = '发送密码邮件时产生错误。请联系管理员！';
$lang['regbadmail']            = '您输入的邮件地址有问题——如果您认为这是系统错误，请联系管理员。';
$lang['regbadpass']            = '您输入的密码与系统产生的不符，请重试。';
$lang['regpwmail']             = '您的 DokuWiki 密码';
$lang['reghere']               = '还没有账号？立即注册';
$lang['profna']                = '本维基不支持修改个人信息';
$lang['profnochange']          = '没有改动，不进行操作。';
$lang['profnoempty']           = '不允许使用空的用户名或邮件地址。';
$lang['profchanged']           = '用户信息更新成功。';
$lang['pwdforget']             = '忘记密码？立即获取新密码';
$lang['resendna']              = '本维基不支持二次发送密码。';
$lang['resendpwd']             = '发送新密码给';
$lang['resendpwdmissing']      = '对不起，您必须填写所有的区域。';
$lang['resendpwdnouser']       = '对不起，在我们的用户数据中找不到该用户。';
$lang['resendpwdbadauth']      = '对不起，该认证码错误。请使用完整的确认链接。';
$lang['resendpwdconfirm']      = '确认链接已经通过邮件发送给您了。';
$lang['resendpwdsuccess']      = '您的新密码已经通过邮件发送给您了。';
$lang['txt_upload']            = '选择要上传的文件';
$lang['txt_filename']          = '上传并重命名为（可选）';
$lang['txt_overwrt']           = '覆盖已存在的同名文件';
$lang['lockedby']              = '目前已被下列人员锁定';
$lang['lockexpire']            = '预计锁定解除于';
$lang['willexpire']            = '您对本页的独有编辑权将于一分钟之后解除。\n为了防止与其他人的编辑冲突，请使用预览按钮重设计时器。';
$lang['notsavedyet']           = '未保存的更改将丢失。\n真的要继续？';
$lang['rssfailed']             = '获取该 RSS 信息时产生错误：';
$lang['nothingfound']          = '什么都没有找到。';
$lang['mediaselect']           = '媒体文件';
$lang['fileupload']            = '上传媒体文件';
$lang['uploadsucc']            = '上传成功';
$lang['uploadfail']            = '上传失败。也许是上传权限错误。';
$lang['uploadwrong']           = '上传失败。该扩展名被禁止。';
$lang['uploadexist']           = '文件已存在。不进行操作。';
$lang['uploadbadcontent']      = '上传的文件与扩展名 %s 不符。';
$lang['uploadspam']            = '上传操作被垃圾信息黑名单阻止。';
$lang['uploadxss']             = '上传操作因可能存在恶意内容而被阻止。';
$lang['deletesucc']            = '文件“%s”已经被删除。';
$lang['deletefail']            = '无法删除“%s”- 请检查权限。';
$lang['mediainuse']            = '文件“%s”无法删除 - 它正被使用中。';
$lang['namespaces']            = '命名空间';
$lang['mediafiles']            = '可用的文件';
$lang['js']['keepopen']        = '选中后不自动关闭窗口';
$lang['js']['hidedetails']     = '隐藏详细信息';
$lang['mediausage']            = '使用下列字符链接到该文件：';
$lang['mediaview']             = '查看该文件';
$lang['mediaroot']             = '根目录';
$lang['mediaupload']           = '上传文件至当前的命名空间。要创建次级命名空间，将其名称加在“上传并重命名为”文件名的前面，并用英文冒号隔开';
$lang['mediaextchange']        = '文件的扩展名由 .%s 改为了 .%s！';
$lang['reference']             = '相关的';
$lang['ref_inuse']             = '该文件无法删除，因为它正被下列页面使用：';
$lang['ref_hidden']            = '一些相关的页面您并没有权限阅读';
$lang['hits']                  = '符合';
$lang['quickhits']             = '匹配的页面名称';
$lang['toc']                   = '目录';
$lang['current']               = '当前版本';
$lang['yours']                 = '您的版本';
$lang['diff']                  = '显示与当前版本的差别';
$lang['line']                  = '行';
$lang['breadcrumb']            = '您的足迹';
$lang['youarehere']            = '您在这里';
$lang['lastmod']               = '最后更改';
$lang['by']                    = '由';
$lang['deleted']               = '移除';
$lang['created']               = '创建';
$lang['restored']              = '已恢复为旧版';
$lang['external_edit']         = '外部编辑';
$lang['summary']               = '编辑摘要';
$lang['mail_newpage']          = '添加页面：';
$lang['mail_changed']          = '更改页面：';
$lang['mail_new_user']         = '新用户：';
$lang['mail_upload']           = '已上传的文件：';
$lang['nosmblinks']            = '连接到 Windows 共享功能只有在 IE 浏览器中才能正常使用。\n但您仍能复制并粘贴该链接。';
$lang['qb_alert']              = '请输入您想格式化的文字。\n它将会被附加到文件的最后。';
$lang['qb_bold']               = '粗体';
$lang['qb_italic']             = '斜体';
$lang['qb_underl']             = '下划线';
$lang['qb_code']               = '代码';
$lang['qb_strike']             = '删除线';
$lang['qb_h1']                 = '标题 H1';
$lang['qb_h2']                 = '标题 H2 ';
$lang['qb_h3']                 = '标题 H3';
$lang['qb_h4']                 = '标题 H4';
$lang['qb_h5']                 = '标题 H5';
$lang['qb_link']               = '内部链接';
$lang['qb_extlink']            = '外部链接';
$lang['qb_hr']                 = '水平线';
$lang['qb_ol']                 = '数字列表项目';
$lang['qb_ul']                 = '普通列表项目';
$lang['qb_media']              = '插入图像或其他文件';
$lang['qb_sig']                = '插入签名';
$lang['qb_smileys']            = '表情符号';
$lang['qb_chars']              = '特殊字符';
$lang['del_confirm']           = '真的要删除选中的项目吗？';
$lang['admin_register']        = '添加新用户';
$lang['metaedit']              = '编辑元数据';
$lang['metasaveerr']           = '写入元数据失败';
$lang['metasaveok']            = '元数据已保存';
$lang['img_backto']            = '返回到';
$lang['img_title']             = '标题';
$lang['img_caption']           = '说明';
$lang['img_date']              = '日期';
$lang['img_fname']             = '名称';
$lang['img_fsize']             = '大小';
$lang['img_artist']            = '摄影师';
$lang['img_copyr']             = '版权';
$lang['img_format']            = '格式';
$lang['img_camera']            = '相机';
$lang['img_keywords']          = '关键字';
$lang['subscribe_success']     = '已将 %s 成功添加到 %s 的订阅列表';
$lang['subscribe_error']       = '无法将 %s 添加到 %s 的订阅列表';
$lang['subscribe_noaddress']   = '您的登录信息中不包含电子邮件地址，您无法加入订阅列表';
$lang['unsubscribe_success']   = '已将 %s 从 %s 的订阅列表中成功删除';
$lang['unsubscribe_error']     = '无法将 %s 从 %s 的订阅列表中删除';
$lang['authmodfailed']         = '错误的用户认证设置。请通知维基管理员。';
$lang['authtempfail']          = '用户认证暂时无法使用。如果该状态一直存在，请通知维基管理员。';
$lang['i_chooselang']          = '选择您的语言';
$lang['i_installer']           = 'DokuWiki 安装工具';
$lang['i_wikiname']            = '维基名称';
$lang['i_enableacl']           = '启用 ACL（推荐）';
$lang['i_superuser']           = '超级用户';
$lang['i_problems']            = '安装工具发现一些问题，已在下面列出。您必须先修复这些问题，才能继续安装。';
$lang['i_modified']            = '由于安全上的考虑，该脚本只能用于全新且做任何改动的 Dokuwiki 安装包。
                         您可以重新解压下载的程序包，或查阅完整的
                         <a href="http://wiki.splitbrain.org/wiki:install">Dokuwiki 安装指南</a>';
$lang['i_funcna']              = 'PHP 功能 <code>%s</code> 无法使用。也许您的服务器提供商因为某些原因禁用了它。';
$lang['i_phpver']              = '您的 PHP 版本 <code>%s</code> 低于最低要求的 <code>%s</code>。您需要升级您的 PHP 版本。';
$lang['i_permfail']            = 'DokuWiki 无法写入 <code>%s</code>。您需要修改该路径的权限设定！';
$lang['i_confexists']          = '<code>%s</code> 已经存在';
$lang['i_writeerr']            = '无法创建 <code>%s</code>。您需要检查该路径/文件的权限设定并手动创建该文件。';
$lang['i_badhash']             = '无法识别的或被修改的 dokuwiki.php（值=<code>%s</code>）';
$lang['i_badval']              = '<code>%s</code> - 非法或空值';
$lang['i_success']             = '配置成功完成。您现在可以删除 install.php 了。继续进入
                        <a href="doku.php">您全新的 DokuWiki</a>。';
$lang['i_failure']             = '写入配置文件的时候产生一些错误。在使用 <a href="doku.php">您全新安装的 DokuWiki</a> 前
                         您需要手动修复它们。';
$lang['i_policy']              = '初始的 ACL 政策';
$lang['i_pol0']                = '开放的维基（任何人都有读、写、上传的权限）';
$lang['i_pol1']                = '公共的维基（任何人都有读的权限，只有注册用户才有写和上传的权限）';
$lang['i_pol2']                = '关闭的维基（只有注册用户才有读、写、上传的权限）';
$lang['i_retry']               = '重试';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/inc/lang/zh/lang.php <==
<?php
/**
 * Chinese(Simplified) language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html) 
 * @author ZDYX <zhangduyixiong@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-tradsimp.html
 * @author George Sheraton guxd@163.com
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = '编辑本页';
$lang['btn_source']            = '显示源文件';
$lang['btn_show']              = '显示页面';
$lang['btn_create']            = '创建该页面';
$lang['btn_search']            = '搜索';
$lang['btn_save']              = '保存';
$lang['btn_preview']           = '预览';
$lang['btn_top']               = '到顶部';
$lang['btn_newer']             = '<< 较新的';
$lang['btn_older']             = '较旧的 >>';
$lang['btn_revs']              = '修订记录';
$lang['btn_recent']            = '最近更改';
$lang['btn_upload']            = '上传';
$lang['btn_cancel']            = '取消';
$lang['btn_index']             = '索引';
$lang['btn_secedit']           = '编辑';
$lang['btn_login']             = '登录';
$lang['btn_logout']            = '退出';
$lang['btn_admin']             = '管理';
$lang['btn_update']            = '更新';
$lang['btn_delete']            = '删除';
$lang['btn_back']              = '返回';
$lang['btn_backlink']          = '反向链接';
$lang['btn_backtomedia']       = '返回到媒体文件选择工具';
$lang['btn_subscribe']         = '订阅本页更改';
$lang['btn_unsubscribe']       = '退订本页更改';
$lang['btn_subscribens']       = '订阅命名空间更改';
$lang['btn_unsubscribens']     = '退订命名空间更改';
$lang['btn_profile']           = '更新个人信息';
$lang['btn_reset']             = '重设';
$lang['btn_resendpwd']         = '发送新密码';
$lang['btn_draft']             = '编辑草稿';
$lang['btn_recover']           = '恢复草稿';
$lang['btn_draftdel']          = '删除草稿';
$lang['loggedinas']            = '登录为';
$lang['user']                  = '用户名';
$lang['pass']                  = '密码';
$lang['newpass']               = '请输入新密码';
$lang['oldpass']               = '请输入当前密码';
$lang['passchk']               = '请再输一次';
$lang['remember']              = '记住我';
$lang['fullname']              = '全名';
$lang['email']                 = 'E-Mail';
$lang['register']              = '注册';
$lang['profile']               = '用户信息';
$lang['badlogin']              = '对不起，用户名或密码错误。';
$lang['minoredit']             = '轻微修改';
$lang['draftdate']             = '草稿自动保存于';
$lang['nosecedit']             = '在您编辑期间本页刚被他人修改过，局部信息已过期，故载入全页。';
$lang['regmissing']            = '对不起，您必须填写所有的区域。';
$lang['reguexists']            = '对不起，该用户名已经存在。';
$lang['regsuccess']            = '新用户已建立，密码将通过电子邮件发送给您。';
$lang['regsuccess2']           = '新用户已建立';
$lang['regmailfail']           = '发送密码邮件时产生错误。请联系管理员！';
$lang['regbadmail']            = '您输入的邮件地址有问题——如果您认为这是系统错误，请联系管理员。';
$lang['regbadpass']            = '您输入的密码与系统产生的不符，请重试。';
$lang['regpwmail']             = '您的 DokuWiki 密码';
$lang['reghere']               = '还没有账号？立即注册';
$lang['profna']                = '本维基不支持修改个人信息';
$lang['profnochange']          = '没有改动，不进行操作。';
$lang['profnoempty']           = '不允许使用空的用户名或邮件地址。';
$lang['profchanged']           = '用户信息更新成功。';
$lang['pwdforget']             = '忘记密码？立即获取新密码';
$lang['resendna']              = '本维基不支持二次发送密码。';
$lang['resendpwd']             = '发送新密码给';
$lang['resendpwdmissing']      = '对不起，您必须填写所有的区域。';
$lang['resendpwdnouser']       = '对不起，在我们的用户数据中找不到该用户。';
$lang['resendpwdbadauth']      = '对不起，该认证码错误。请使用完整的确认链接。';
$lang['resendpwdconfirm']      = '确认链接已经通过邮件发送给您了。';
$lang['resendpwdsuccess']      = '您的新密码已经通过邮件发送给您了。';
$lang['license']               = '除额外注明的地方外，本维基上的内容按下列许可协议发布：';
$lang['licenseok']             = '当您选择开始编辑本页，即寓示你同意将你贡献的内容按下列许可协议发布：';
$lang['txt_upload']            = '选择要上传的文件';
$lang['txt_filename']          = '上传并重命名为（可选）';
$lang['txt_overwrt']           = '覆盖已存在的同名文件';
$lang['lockedby']              = '目前已被下列人员锁定';
$lang['lockexpire']            = '预计锁定解除于';
$lang['willexpire']            = '您对本页的独有编辑权将于一分钟之后解除。\n为了防止与其他人的编辑冲突，请使用预览按钮重设计时器。';
$lang['notsavedyet']           = '未保存的更改将丢失。\n真的要继续？';
$lang['rssfailed']             = '获取该 RSS 信息时产生错误：';
$lang['nothingfound']          = '什么都没有找到。';
$lang['mediaselect']           = '媒体文件';
$lang['fileupload']            = '上传媒体文件';
$lang['uploadsucc']            = '上传成功';
$lang['uploadfail']            = '上传失败。也许是上传权限错误。';
$lang['uploadwrong']           = '上传失败。该扩展名被禁止。';
$lang['uploadexist']           = '文件已存在。不进行操作。';
$lang['uploadbadcontent']      = '上传的文件与扩展名 %s 不符。';
$lang['uploadspam']            = '上传操作被垃圾信息黑名单阻止。';
$lang['uploadxss']             = '上传操作因可能存在恶意内容而被阻止。';
$lang['uploadsize']            = '上传的文件过大。（最大 %s)';
$lang['deletesucc']            = '文件“%s”已经被删除。';
$lang['deletefail']            = '无法删除“%s”- 请检查权限。';
$lang['mediainuse']            = '文件“%s”无法删除 - 它正被使用中。';
$lang['namespaces']            = '命名空间';
$lang['mediafiles']            = '可用的文件';
$lang['js']['keepopen']        = '选中后不自动关闭窗口';
$lang['js']['hidedetails']     = '隐藏详细信息';
$lang['js']['nosmblinks']      = '连接到 Windows 共享功能只有在 IE 浏览器中才能正常使用。
但您仍能复制并粘贴该链接。';
$lang['js']['mu_btn']          = '一次上传了多个文件';
$lang['mediausage']            = '使用下列字符链接到该文件：';
$lang['mediaview']             = '查看该文件';
$lang['mediaroot']             = '根目录';
$lang['mediaupload']           = '上传文件至当前的命名空间。要创建次级命名空间，将其名称加在“上传并重命名为”文件名的前面，并用英文冒号隔开';
$lang['mediaextchange']        = '文件的扩展名由 .%s 改为了 .%s！';
$lang['reference']             = '相关的';
$lang['ref_inuse']             = '该文件无法删除，因为它正被下列页面使用：';
$lang['ref_hidden']            = '一些相关的页面您并没有权限阅读';
$lang['hits']                  = '符合';
$lang['quickhits']             = '匹配的页面名称';
$lang['toc']                   = '目录';
$lang['current']               = '当前版本';
$lang['yours']                 = '您的版本';
$lang['diff']                  = '显示与当前版本的差别';
$lang['diff2']                 = '显示跟目前版本的差异';
$lang['line']                  = '行';
$lang['breadcrumb']            = '您的足迹';
$lang['youarehere']            = '您在这里';
$lang['lastmod']               = '最后更改';
$lang['by']                    = '由';
$lang['deleted']               = '移除';
$lang['created']               = '创建';
$lang['restored']              = '已恢复为旧版';
$lang['external_edit']         = '外部编辑';
$lang['summary']               = '编辑摘要';
$lang['noflash']               = '需要 <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash 插件</a> 来播放本内容。 ';
$lang['mail_newpage']          = '添加页面：';
$lang['mail_changed']          = '更改页面：';
$lang['mail_new_user']         = '新用户：';
$lang['mail_upload']           = '已上传的文件：';
$lang['qb_alert']              = '请输入您想格式化的文字。\n它将会被附加到文件的最后。';
$lang['qb_bold']               = '粗体';
$lang['qb_italic']             = '斜体';
$lang['qb_underl']             = '下划线';
$lang['qb_code']               = '代码';
$lang['qb_strike']             = '删除线';
$lang['qb_h1']                 = '标题 H1';
$lang['qb_h2']                 = '标题 H2 ';
$lang['qb_h3']                 = '标题 H3';
$lang['qb_h4']                 = '标题 H4';
$lang['qb_h5']                 = '标题 H5';
$lang['qb_link']               = '内部链接';
$lang['qb_extlink']            = '外部链接';
$lang['qb_hr']                 = '水平线';
$lang['qb_ol']                 = '数字列表项目';
$lang['qb_ul']                 = '普通列表项目';
$lang['qb_media']              = '插入图像或其他文件';
$lang['qb_sig']                = '插入签名';
$lang['qb_smileys']            = '表情符号';
$lang['qb_chars']              = '特殊字符';
$lang['del_confirm']           = '真的要删除选中的项目吗？';
$lang['admin_register']        = '添加新用户';
$lang['metaedit']              = '编辑元数据';
$lang['metasaveerr']           = '写入元数据失败';
$lang['metasaveok']            = '元数据已保存';
$lang['img_backto']            = '返回到';
$lang['img_title']             = '标题';
$lang['img_caption']           = '说明';
$lang['img_date']              = '日期';
$lang['img_fname']             = '名称';
$lang['img_fsize']             = '大小';
$lang['img_artist']            = '摄影师';
$lang['img_copyr']             = '版权';
$lang['img_format']            = '格式';
$lang['img_camera']            = '相机';
$lang['img_keywords']          = '关键字';
$lang['subscribe_success']     = '已将 %s 成功添加到 %s 的订阅列表';
$lang['subscribe_error']       = '无法将 %s 添加到 %s 的订阅列表';
$lang['subscribe_noaddress']   = '您的登录信息中不包含电子邮件地址，您无法加入订阅列表';
$lang['unsubscribe_success']   = '已将 %s 从 %s 的订阅列表中成功删除';
$lang['unsubscribe_error']     = '无法将 %s 从 %s 的订阅列表中删除';
$lang['authmodfailed']         = '错误的用户认证设置。请通知维基管理员。';
$lang['authtempfail']          = '用户认证暂时无法使用。如果该状态一直存在，请通知维基管理员。';
$lang['i_chooselang']          = '选择您的语言';
$lang['i_installer']           = 'DokuWiki 安装工具';
$lang['i_wikiname']            = '维基名称';
$lang['i_enableacl']           = '启用 ACL（推荐）';
$lang['i_superuser']           = '超级用户';
$lang['i_problems']            = '安装工具发现一些问题，已在下面列出。您必须先修复这些问题，才能继续安装。';
$lang['i_modified']            = '由于安全上的考虑，该脚本只能用于全新且做任何改动的 Dokuwiki 安装包。
                         您可以重新解压下载的程序包，或查阅完整的
                         <a href="http://dokuwiki.org/install">Dokuwiki 安装指南</a>';
$lang['i_funcna']              = 'PHP 功能 <code>%s</code> 无法使用。也许您的服务器提供商因为某些原因禁用了它。';
$lang['i_phpver']              = '您的 PHP 版本 <code>%s</code> 低于最低要求的 <code>%s</code>。您需要升级您的 PHP 版本。';
$lang['i_permfail']            = 'DokuWiki 无法写入 <code>%s</code>。您需要修改该路径的权限设定！';
$lang['i_confexists']          = '<code>%s</code> 已经存在';
$lang['i_writeerr']            = '无法创建 <code>%s</code>。您需要检查该路径/文件的权限设定并手动创建该文件。';
$lang['i_badhash']             = '无法识别的或被修改的 dokuwiki.php（值=<code>%s</code>）';
$lang['i_badval']              = '<code>%s</code> - 非法或空值';
$lang['i_success']             = '配置成功完成。您现在可以删除 install.php 了。继续进入
                        <a href="doku.php">您全新的 DokuWiki</a>。';
$lang['i_failure']             = '写入配置文件的时候产生一些错误。在使用 <a href="doku.php">您全新安装的 DokuWiki</a> 前
                         您需要手动修复它们。';
$lang['i_policy']              = '初始的 ACL 政策';
$lang['i_pol0']                = '开放的维基（任何人都有读、写、上传的权限）';
$lang['i_pol1']                = '公共的维基（任何人都有读的权限，只有注册用户才有写和上传的权限）';
$lang['i_pol2']                = '关闭的维基（只有注册用户才有读、写、上传的权限）';
$lang['i_retry']               = '重试';
$lang['mu_intro']              = '您可以在此一次上传多个文件。点按浏览按钮添加文件到上传队列中，先好后按上传钮。';
$lang['mu_gridname']           = '文件名';
$lang['mu_gridsize']           = '大小';
$lang['mu_gridstat']           = '状态';
$lang['mu_namespace']          = '名称空间';
$lang['mu_browse']             = '浏览';
$lang['mu_toobig']             = '过大';
$lang['mu_ready']              = '准备好上传';
$lang['mu_done']               = '完成';
$lang['mu_fail']               = '失败';
$lang['mu_authfail']           = '会话过期';
$lang['mu_progress']           = '@PCT@% 上传完成';
$lang['mu_filetypes']          = '允许的文件类型';
$lang['recent_global']         = '您当前看到的是<b>%s</b> 名称空间的变动。你还可以在<a href="%s">查看整个维基的近期变动</a>。';
